trident.callbacks package
=========================

Submodules
----------

trident.callbacks.data\_flow\_callbacks module
----------------------------------------------

.. automodule:: trident.callbacks.data_flow_callbacks
   :members:
   :undoc-members:
   :show-inheritance:

trident.callbacks.gan\_callbacks module
---------------------------------------

.. automodule:: trident.callbacks.gan_callbacks
   :members:
   :undoc-members:
   :show-inheritance:

trident.callbacks.lr\_schedulers module
---------------------------------------

.. automodule:: trident.callbacks.lr_schedulers
   :members:
   :undoc-members:
   :show-inheritance:

trident.callbacks.regularization\_callbacks module
--------------------------------------------------

.. automodule:: trident.callbacks.regularization_callbacks
   :members:
   :undoc-members:
   :show-inheritance:

trident.callbacks.saving\_strategies module
-------------------------------------------

.. automodule:: trident.callbacks.saving_strategies
   :members:
   :undoc-members:
   :show-inheritance:

trident.callbacks.visualization\_callbacks module
-------------------------------------------------

.. automodule:: trident.callbacks.visualization_callbacks
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: trident.callbacks
   :members:
   :undoc-members:
   :show-inheritance:
